@@ -36,7 +36,8 @@
   #:use-module (cv support keyword)
   #:use-module (cv support modules)
   #:use-module (cv support f32vector)
-  
+  #:use-module (cv support libguile-cv)
+
   #:duplicates (merge-generics
 		replace
 		warn-override-core
@@ -53,4 +54,5 @@
 			      (cv support push)
 			      (cv support keyword)
 			      (cv support modules)
-			      (cv support f32vector)))
+			      (cv support f32vector)
+                              (cv support libguile-cv)))
