@@ -231,5 +231,72 @@
     (assert-true (im-=? (im-multiply a 2.0) c))
     (assert-true (im-=? (im-divide c 2.0) a))))
 
+(define (make-scrap-test-image)
+  (let ((img (im-make 12 12 1)))
+    (for-each (lambda (pos)
+		(match pos
+		  ((i j) (im-set! img i j 1.0))))
+	'((1 1) (1 2)
+          (2 1) (2 2)
+          (4 4) (4 5) (4 6)
+          (5 4) (5 5) (5 6)
+          (6 4) (6 5) (6 6)
+          (8 8) (8 9) (8 10) (8 11)
+          (9 8) (9 9) (9 10) (9 11)
+          (10 8) (10 9) (10 10) (10 11)
+          (11 8) (11 9) (11 10) (11 11)
+	  ))
+    img))
+
+(define (make-scrap-test-<)
+  (let ((img (im-make 12 12 1)))
+    (for-each (lambda (pos)
+		(match pos
+		  ((i j) (im-set! img i j 1.0))))
+	'((4 4) (4 5) (4 6)
+          (5 4) (5 5) (5 6)
+          (6 4) (6 5) (6 6)
+          (8 8) (8 9) (8 10) (8 11)
+          (9 8) (9 9) (9 10) (9 11)
+          (10 8) (10 9) (10 10) (10 11)
+          (11 8) (11 9) (11 10) (11 11)
+	  ))
+    img))
+
+(define (make-scrap-test-=)
+  (let ((img (im-make 12 12 1)))
+    (for-each (lambda (pos)
+		(match pos
+		  ((i j) (im-set! img i j 1.0))))
+	'((1 1) (1 2)
+          (2 1) (2 2)
+          (8 8) (8 9) (8 10) (8 11)
+          (9 8) (9 9) (9 10) (9 11)
+          (10 8) (10 9) (10 10) (10 11)
+          (11 8) (11 9) (11 10) (11 11)
+	  ))
+    img))
+
+(define (make-scrap-test->)
+  (let ((img (im-make 12 12 1)))
+    (for-each (lambda (pos)
+		(match pos
+		  ((i j) (im-set! img i j 1.0))))
+	'((1 1) (1 2)
+          (2 1) (2 2)
+          (4 4) (4 5) (4 6)
+          (5 4) (5 5) (5 6)
+          (6 4) (6 5) (6 6)))
+    img))
+
+(define-method (test-adds-3 (self <guile-cv-tests-cv>))
+  (let ((a (make-scrap-test-image))
+        (b (make-scrap-test-<))
+        (c (make-scrap-test-=))
+        (d (make-scrap-test->)))
+    (assert-true (im-=? (im-scrap a 5) b))
+    (assert-true (im-=? (im-scrap a 9 #:pred =) c))
+    (assert-true (im-=? (im-scrap a 9 #:pred >) d))))
+
 
 (exit-with-summary (run-all-defined-test-cases))
